@@ -4,27 +4,24 @@ function(model) {
 	std.coef(model, FALSE)
 }
 
+
 .vif <-
 function(x) {
 	v <- vcov(x)
+	nam <- dimnames(v)[[1L]]
 	if(dim(v)[1L] < 2L) return(structure(rep_len(1, dim(v)[1L]),
 										 names = dimnames(v)[[1L]]))
-	if ((ndef <- sum(is.na(coef(x)))) > 0L) 
+	if ((ndef <- sum(is.na(coeffs(x)))) > 0L) 
         stop(sprintf(ngettext(ndef, "one coefficient is not defined",
 			"%d coefficients are not defined"), ndef))
 	o <- attr(model.matrix(x), "assign")
 	if (any(int <-(o == 0))) {
 		v <- v[!int, !int, drop = FALSE]
 	} else warning("no intercept: VIFs may not be sensible")
-	R <- cov2cor(v)
-	detR <- det(R)
-	vfs <- numeric(m <- dim(v)[1L])
-	for (j in 1L:m)
-		vfs[j] <- det(as.matrix(R[j, j])) * det(as.matrix(R[-j,-j])) / detR
-	
-	rval <- numeric(length(int))
-	names(rval) <- dimnames(vcov(x))[[1L]]
-	rval[!int] <- vfs
+	d <- sqrt(diag(v))
+	rval <- numeric(length(nam))
+	names(rval) <- nam
+	rval[!int] <- diag(solve(v / (d %o% d)))
 	rval[int] <- 1
 	rval
 }
@@ -36,7 +33,8 @@ function(x, sd, vif, n, p = length(x) - 1) {
 
 partial.sd <- function(x) {
 	mm <- model.matrix(x)
-	.partialsd(coef(x), apply(mm, 2L, sd), .vif(x), nobs(x), sum(attr(mm, "assign") != 0))
+	.partialsd(coef(x), apply(mm, 2L, sd), .vif(x), nobs(x),
+			   sum(attr(mm, "assign") != 0))
 }
 
 `std.coef` <-
